@@ -20,7 +20,7 @@ import enum
 import os
 import shutil
 import tempfile
-
+from util import delete_tempfile
 
 class QemuEfiMachine(enum.Enum):
     OVMF_PC = enum.auto()
@@ -202,19 +202,15 @@ class QemuCommand:
                 (code_path),
             ]
             if vars_template_path is None:
-                self.varfile_path = None
                 return
-            with tempfile.NamedTemporaryFile(delete=False) as varfile:
-                self.varfile_path = varfile.name
-                with open(vars_template_path, 'rb') as template:
-                    shutil.copyfileobj(template, varfile)
-                    self.params = self.params + [
-                        '-drive',
-                        'file=%s,if=pflash,format=raw,unit=1,readonly=off' %
-                        (varfile.name)
-                    ]
-
-        def __del__(self):
-            if self.varfile_path is None:
-                return
-            os.unlink(self.varfile_path)
+            self.varfile = tempfile.NamedTemporaryFile(
+                prefix=os.path.basename(vars_template_path),
+                delete=delete_tempfile(),
+            )
+            with open(vars_template_path, 'rb') as template:
+                shutil.copyfileobj(template, self.varfile)
+                self.params = self.params + [
+                    '-drive',
+                    'file=%s,if=pflash,format=raw,unit=1,readonly=off' %
+                    (self.varfile.name)
+                ]
