@@ -17,6 +17,7 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import logging
 import os
 import pexpect
 import subprocess
@@ -91,6 +92,7 @@ class BootToShellTest(unittest.TestCase):
         sys.stdout.write("%s runtime: %.3fs\n" % (self.id(), t))
 
     def run_cmd_check_shell(self, cmd, should_start=True):
+        logger.debug(f"Running: {' '.join(cmd)}")
         child = pexpect.spawn(' '.join(cmd), encoding='UTF-8')
         shell_started = None
 
@@ -122,6 +124,7 @@ class BootToShellTest(unittest.TestCase):
         self.assertEqual(should_start, shell_started)
 
     def run_cmd_check_secure_boot(self, cmd, efiarch, should_verify):
+        logger.debug(f"Running: {' '.join(cmd)}")
         child = pexpect.spawn(' '.join(cmd), encoding='UTF-8')
 
         if self.debug:
@@ -175,6 +178,23 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'aa64', True)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH'] == 'arm64', "Requires grub-efi-arm64",
+    )
+    def test_aavmf_ms_secure_boot_strictnx_signed(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.AAVMF,
+            variant=QemuEfiVariant.MS_STRICTNX,
+        )
+        grub = get_local_grub_path('AA64', signed=True)
+        shim = get_local_shim_path('AA64', signed=True)
+        iso = GrubShellBootableIsoImage('AA64', shim, grub)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'aa64', True)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -188,6 +208,19 @@ class BootToShellTest(unittest.TestCase):
         )
         self.run_cmd_check_shell(q.command, should_start=False)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH'] == 'arm64', "Requires grub-efi-arm64",
+    )
+    def test_aavmf_ms_secure_boot_strictnx_no_shell(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.AAVMF,
+            variant=QemuEfiVariant.MS_STRICTNX,
+        )
+        self.run_cmd_check_shell(q.command, should_start=False)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -205,6 +238,23 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'aa64', False)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH'] == 'arm64', "Requires grub-efi-arm64",
+    )
+    def test_aavmf_ms_secure_boot_strictnx_unsigned(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.AAVMF,
+            variant=QemuEfiVariant.MS_STRICTNX,
+        )
+        grub = get_local_grub_path('AA64', signed=False)
+        shim = get_local_shim_path('AA64', signed=False)
+        iso = GrubShellBootableIsoImage('AA64', shim, grub)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'aa64', False)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -289,6 +339,18 @@ class BootToShellTest(unittest.TestCase):
         )
         self.run_cmd_check_shell(q.command, should_start=False)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(DpkgArch['DEB_BUILD_ARCH'] == 'amd64', "amd64-only")
+    def test_ovmf_4m_ms_secure_boot_strictnx_no_shell(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.OVMF_Q35,
+            variant=QemuEfiVariant.MS_STRICTNX,
+            flash_size=QemuEfiFlashSize.SIZE_4MB,
+        )
+        self.run_cmd_check_shell(q.command, should_start=False)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -305,6 +367,22 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', True)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(DpkgArch['DEB_BUILD_ARCH'] == 'amd64', "amd64-only")
+    def test_ovmf_4m_ms_secure_boot_strictnx_signed(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.OVMF_Q35,
+            variant=QemuEfiVariant.MS_STRICTNX,
+            flash_size=QemuEfiFlashSize.SIZE_4MB,
+        )
+        grub = get_local_grub_path('X64', signed=True)
+        shim = get_local_shim_path('X64', signed=True)
+        iso = GrubShellBootableIsoImage('X64', shim, grub)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'x64', True)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -321,6 +399,22 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', False)
 
+    @unittest.skipUnless(
+        DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
+    )
+    @unittest.skipUnless(DpkgArch['DEB_BUILD_ARCH'] == 'amd64', "amd64-only")
+    def test_ovmf_4m_ms_secure_boot_strictnx_unsigned(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.OVMF_Q35,
+            variant=QemuEfiVariant.MS_STRICTNX,
+            flash_size=QemuEfiFlashSize.SIZE_4MB,
+        )
+        grub = get_local_grub_path('X64', signed=False)
+        shim = get_local_shim_path('X64', signed=False)
+        iso = GrubShellBootableIsoImage('X64', shim, grub)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'x64', False)
+
     @unittest.skipUnless(
         DpkgArch['DEB_BUILD_ARCH_BITS'] == '64', "Requires 64-bit QEMU",
     )
@@ -395,4 +489,6 @@ class BootToShellTest(unittest.TestCase):
         self.run_cmd_check_shell(q.command)
 
 if __name__ == '__main__':
+    logger = logging.getLogger(__name__)
+    logging.basicConfig(level=logging.DEBUG)
     unittest.main(verbosity=2)
